======================
Parameters and Objects
======================

Descriptors
===========

.. autoclass:: easyCore.Objects.Base.Descriptor
  :members:

Parameters
==========

.. autoclass:: easyCore.Objects.Base.Parameter
  :members:
  :inherited-members:

=============================
Super Classes and Collections
=============================

Super Classes
=============

.. autoclass:: easyCore.Objects.Base.BasedBase
  :members:
  :inherited-members:

.. autoclass:: easyCore.Objects.Base.BaseObj
  :members: +_add_component
  :inherited-members:

Collections
===========

.. autoclass:: easyCore.Objects.Groups.BaseCollection
  :members:
  :inherited-members:

===============
Data Containers
===============

.. autoclass:: easyCore.Datasets.xarray.easyCoreDataarrayAccessor
  :members:
  :inherited-members:

.. autoclass:: easyCore.Datasets.xarray.easyCoreDatasetAccessor
  :members:
  :inherited-members:

